import * as vscode from 'vscode';
import { QuickPickItem } from "vscode";

function codeGeneratorQuickPickLogic(): undefined {
    const textEditor = vscode.window.activeTextEditor;
    if (!textEditor) {
        return undefined;
    }
    let thenable = vscode.window.showQuickPick(
        [
            {
                label: "Class name",
                detail: "Segments Minus One (Object || Array)",
                output: "$ClassName$"
            }, {
                label: "Type",
                detail: "Segments Minus One (!Object && !Array)",
                output: "$Type$"
            }, {
                label: "Suggested Type",
                detail: "Type based on values in *.json file",
                output: "$SuggestedType$"
            }, {
                label: "Full Path",
                detail: "Full Path and name in padded format",
                output: "$Debug$"
            }, {
                label: "Name",
                detail: "Segments Last only name (no path)",
                output: "$Name$"
            }, {
                label: "Class name (Camel-Cased)",
                detail: "Segments Minus One (Object || Array)",
                output: "ClassNameCamel$"
            }, {
                label: "Type (Camel-Cased)",
                detail: "Segments Minus One (!Object && !Array)",
                output: "TypeCamel$"
            }, {
                label: "Suggested Type (Camel-Cased)",
                detail: "Type based on values in *.json file",
                output: "SuggestedTypeCamel$"
            }, {
                label: "Full Path (Camel-Cased)",
                detail: "Full Path and name in padded format",
                output: "$DebugCamel$"
            }, {
                label: "Name (Camel-Cased)",
                detail: "Segments Last only name (no path)",
                output: "$NameCamel$"
            }, {
                label: "Name (Camel-Cased and Plural)",
                detail: "Segments Last only name (no path)",
                output: "$NameCamelPlural$"
            }
        ]
    ).then(item => {
        if (!item) {
            return;
        }
        const selection = textEditor.selection;
        return textEditor.edit(editBuilder => {
            var range;
            if (selection.isEmpty) {
                editBuilder.insert(selection.start, item.output)
            }
            else {
                range = new vscode.Range(selection.start.line, selection.start.character, selection.end.line, selection.end.character);
                editBuilder.replace(range, item.output);
            }
        });
    });
    return undefined;
}

export const codeGeneratorQuickPick = () => codeGeneratorQuickPickLogic();
export const open = () => codeGeneratorQuickPickLogic();